@@ -1,6 +1,10 @@
 # -*- coding: utf-8 -*-
 """
-Combinatorial Functions
+Combinatorics
+
+Combinatorics is an area of mathematics primarily concerned with counting, both as a means and an end in obtaining results, and certain properties of finite structures.
+
+It is closely related to many other areas of mathematics and has many applications ranging from logic to statistical physics, from evolutionary biology to computer science, etc.
 """
 
 
