@@ -2,7 +2,13 @@
 # -*- coding: utf-8 -*-
 
 """
-Control Statements
+Procedural Programming
+
+Procedural programming is a programming paradigm, derived from imperative programming, based on the concept of the procedure call.
+
+Procedures (a type of routine or subroutine) simply contain a series of computational steps to be carried out. Any given procedure might be called at any point during a program's execution, including by other procedures or itself.
+
+Procedural functions and are integrated into Mathics symbolic programming environment.
 """
 
 
@@ -41,18 +47,6 @@ class CompoundExpression(BinaryOperator):
     >> a;
 
     ## Parser Tests
-    #> FullForm[Hold[a ;]]
-     = Hold[CompoundExpression[a, Null]]
-    #> FullForm[Hold[a ; b]]
-     = Hold[CompoundExpression[a, b]]
-    #> FullForm[Hold[a ; b ;]]
-     = Hold[CompoundExpression[a, b, Null]]
-    #> FullForm[Hold[a ; b ; c]]
-     = Hold[CompoundExpression[a, b, c]]
-    #> FullForm[Hold[a ; ; c]]
-     = Hold[CompoundExpression[a, Null, c]]
-    #> FullForm[Hold[a ; ;]]
-     = Hold[CompoundExpression[a, Null, Null]]
     #> FullForm[Hold[; a]]
      : "FullForm[Hold[" cannot be followed by "; a]]" (line 1 of "<test>").
     #> FullForm[Hold[; a ;]]
@@ -82,6 +76,8 @@ class CompoundExpression(BinaryOperator):
     ## Issue 531
     #> z = Max[1, 1 + x]; x = 2; z
      = 3
+
+    #> Clear[x]; Clear[z]
     """
 
     operator = ";"
@@ -168,8 +164,8 @@ class Switch(Builtin):
      = y
     >> Switch[5, 1, x, 2, y]
      = Switch[5, 1, x, 2, y]
-    >> Switch[5, 1, x, 2, y, _, z]
-     = z
+    >> Switch[5, 1, x, 2, a, _, b]
+     = b
     >> Switch[2, 1]
      : Switch called with 2 arguments. Switch must be called with an odd number of arguments.
      = Switch[2, 1]
@@ -221,6 +217,8 @@ class Which(Builtin):
     >> f[-3]
      = 3
 
+    #> Clear[f]
+
     If no test yields 'True', 'Which' returns 'Null':
     >> Which[False, a]
 
@@ -679,6 +677,8 @@ class Return(Builtin):
     >> f[-1]
      = 0
 
+    #> Clear[f]
+
     >> Do[If[i > 3, Return[]]; Print[i], {i, 10}]
      | 1
      | 2
@@ -760,29 +760,30 @@ class Continue(Builtin):
 class Catch(Builtin):
     """
     <dl>
-    <dt>'Catch[`expr`]'
-        <dd> returns the argument of the first Throw generated in the evaluation of expr.
+      <dt>'Catch[$expr$]'
+      <dd> returns the argument of the first 'Throw' generated in the evaluation of $expr$.
 
-    <dt>'Catch[`expr`, `form`]'
-        <dd> returns value from the first Throw[`value`,`tag`] for which form matches `tag`.
+      <dt>'Catch[$expr$, $form$]'
+      <dd> returns value from the first 'Throw[$value$, $tag$]' for which $form$ matches $tag$.
 
-    <dt>'Catch[`expr`,`form`, `f`]'
-        <dd> returns the argument of the first `Throw` generated in the evaluation of `expr`.
+      <dt>'Catch[$expr$, $form$, $f$]'
+      <dd> returns $f$[$value$, $tag$].
     </dl>
 
-    Exit to the enclosing Catch as soon as Throw is evaluated:
-    << Catch[r; s; Throw[t]; u; v]
+    Exit to the enclosing 'Catch' as soon as 'Throw' is evaluated:
+    >> Catch[r; s; Throw[t]; u; v]
      = t
 
     Define a function that can "throw an exception":
-    << f[x_] := If[x > 12, Throw[overflow], x!]
-     = ...
-    The result of Catch is just what is thrown by Throw:
-    << Catch[f[1] + f[15]]
-     = overflow
-    << Catch[f[1]+f[4]]
-     = 24
+    >> f[x_] := If[x > 12, Throw[overflow], x!]
 
+    The result of 'Catch' is just what is thrown by 'Throw':
+    >> Catch[f[1] + f[15]]
+     = overflow
+    >> Catch[f[1] + f[4]]
+     = 25
+
+    #> Clear[f]
     """
 
     attributes = ("HoldAll",)
@@ -820,16 +821,16 @@ class Throw(Builtin):
 
     <dt>'Catch[`value`, `tag`]'
         <dd> is caught only by `Catch[expr,form]`, where tag matches form.
-
     </dl>
 
-     Using Throw can affect the structure of what is returned by a function:
+    Using Throw can affect the structure of what is returned by a function:
 
-     << NestList[#^2 + 1 &, 1, 7]
-      = ...
-     << Catch[NestList[If[# > 1000, Throw[#], #^2 + 1] &, 1, 7]]
-      = 458330
-     << Throw[1]
+    >> NestList[#^2 + 1 &, 1, 7]
+     = ...
+    >> Catch[NestList[If[# > 1000, Throw[#], #^2 + 1] &, 1, 7]]
+     = 458330
+
+    X> Throw[1]
       = Null
     """
 
