@@ -5,7 +5,9 @@ Image[] and image related functions.
 Note that you (currently) need scikit-image installed in order for this module to work.
 """
 from mathics.version import __version__  # noqa used in loading to check consistency.
-from mathics.builtin.base import Builtin, AtomBuiltin, Test, BoxConstruct, String
+
+from mathics.builtin.base import Builtin, AtomBuiltin, Test, String
+from mathics.builtin.box.image import ImageBox
 from mathics.core.expression import (
     Atom,
     Expression,
@@ -21,14 +23,13 @@ from mathics.core.expression import (
     SymbolRule,
     from_python,
 )
-from mathics.builtin.drawing.colors import (
-    convert as convert_color,
+from mathics.builtin.colors.color_internals import (
+    convert_color,
     colorspaces as known_colorspaces,
 )
 
 import base64
 import functools
-import itertools
 import math
 from collections import defaultdict
 
@@ -1263,59 +1264,6 @@ class ImageColorSpace(_ImageBuiltin):
         return String(image.color_space)
 
 
-class ColorConvert(Builtin):
-    """
-    <dl>
-    <dt>'ColorConvert[$c$, $colspace$]'
-        <dd>returns the representation of $c$ in the color space $colspace$. $c$
-        may be a color or an image.
-    </dl>
-
-    Valid values for $colspace$ are:
-
-    CMYK: convert to CMYKColor
-    Grayscale: convert to GrayLevel
-    HSB: convert to Hue
-    LAB: concert to LABColor
-    LCH: convert to LCHColor
-    LUV: convert to LUVColor
-    RGB: convert to RGBColor
-    XYZ: convert to XYZColor
-    """
-
-    messages = {
-        "ccvinput": "`` should be a color.",
-        "imgcstype": "`` is not a valid color space.",
-    }
-
-    def apply(self, input, colorspace, evaluation):
-        "ColorConvert[input_, colorspace_String]"
-
-        if isinstance(input, Image):
-            return input.color_convert(colorspace.get_string_value())
-        else:
-            from mathics.builtin.graphics import (
-                expression_to_color,
-                color_to_expression,
-            )
-
-            py_color = expression_to_color(input)
-            if py_color is None:
-                evaluation.message("ColorConvert", "ccvinput", input)
-                return
-
-            py_colorspace = colorspace.get_string_value()
-            converted_components = convert_color(
-                py_color.components, py_color.color_space, py_colorspace
-            )
-
-            if converted_components is None:
-                evaluation.message("ColorConvert", "imgcstype", colorspace)
-                return
-
-            return color_to_expression(converted_components, py_colorspace)
-
-
 class ColorQuantize(_ImageBuiltin):
     """
     <dl>
@@ -1443,35 +1391,6 @@ class Binarize(_SkimageBuiltin):
         return Image(mask1 * mask2, "Grayscale")
 
 
-class ColorNegate(_ImageBuiltin):
-    """
-    <dl>
-      <dt>'ColorNegate[$image$]'
-      <dd>returns the negative of $image$ in which colors have been negated.
-
-      <dt>'ColorNegate[$color$]'
-      <dd>returns the negative of a color.
-
-      Yellow is RGBColor[1.0, 1.0, 0.0]
-      >> ColorNegate[Yellow]
-       = RGBColor[0., 0., 1.]
-    </dl>
-    """
-
-    def apply_for_image(self, image, evaluation):
-        "ColorNegate[image_Image]"
-        return image.filter(lambda im: PIL.ImageOps.invert(im))
-
-    def apply_for_color(self, color, evaluation):
-        "ColorNegate[color_RGBColor]"
-        # Get components
-        r, g, b = [leaf.to_python() for leaf in color.leaves]
-        # Invert
-        r, g, b = (1.0 - r, 1.0 - g, 1.0 - b)
-        # Reconstitute
-        return Expression("RGBColor", Real(r), Real(g), Real(b))
-
-
 class ColorSeparate(_ImageBuiltin):
     """
     <dl>
@@ -1614,172 +1533,6 @@ class Colorize(_ImageBuiltin):
         )
 
 
-class DominantColors(_ImageBuiltin):
-    """
-    <dl>
-    <dt>'DominantColors[$image$]'
-      <dd>gives a list of colors which are dominant in the given image.
-    <dt>'DominantColors[$image$, $n$]'
-      <dd>returns at most $n$ colors.
-    <dt>'DominantColors[$image$, $n$, $prop$]'
-      <dd>returns the given property $prop$, which may be "Color" (return RGB colors), "LABColor" (return
-      LAB colors), "Count" (return the number of pixels a dominant color covers), "Coverage" (return the
-      fraction of the image a dominant color covers), or "CoverageImage" (return a black and white image
-      indicating with white the parts that are covered by a dominant color).
-    </dl>
-
-    The option "ColorCoverage" specifies the minimum amount of coverage needed to include a dominant color
-    in the result.
-
-    The option "MinColorDistance" specifies the distance (in LAB color space) up to which colors are merged
-    and thus regarded as belonging to the same dominant color.
-
-    >> img = Import["ExampleData/lena.tif"]
-     = -Image-
-
-    >> DominantColors[img]
-     = {RGBColor[0.827451, 0.537255, 0.486275], RGBColor[0.87451, 0.439216, 0.45098], RGBColor[0.341176, 0.0705882, 0.254902], RGBColor[0.690196, 0.266667, 0.309804], RGBColor[0.533333, 0.192157, 0.298039], RGBColor[0.878431, 0.760784, 0.721569]}
-
-    >> DominantColors[img, 3]
-     = {RGBColor[0.827451, 0.537255, 0.486275], RGBColor[0.87451, 0.439216, 0.45098], RGBColor[0.341176, 0.0705882, 0.254902]}
-
-    >> DominantColors[img, 3, "Coverage"]
-     = {28579 / 131072, 751 / 4096, 23841 / 131072}
-
-    >> DominantColors[img, 3, "CoverageImage"]
-     = {-Image-, -Image-, -Image-}
-
-    >> DominantColors[img, 3, "Count"]
-     = {57158, 48064, 47682}
-
-    >> DominantColors[img, 2, "LABColor"]
-     = {LABColor[0.646831, 0.279785, 0.193184], LABColor[0.608465, 0.443559, 0.195911]}
-
-    >> DominantColors[img, MinColorDistance -> 0.5]
-     = {RGBColor[0.87451, 0.439216, 0.45098], RGBColor[0.341176, 0.0705882, 0.254902]}
-
-    >> DominantColors[img, ColorCoverage -> 0.15]
-     = {RGBColor[0.827451, 0.537255, 0.486275], RGBColor[0.87451, 0.439216, 0.45098], RGBColor[0.341176, 0.0705882, 0.254902]}
-    """
-
-    rules = {
-        "DominantColors[image_Image, n_Integer, options___]": 'DominantColors[image, n, "Color", options]',
-        "DominantColors[image_Image, options___]": 'DominantColors[image, 256, "Color", options]',
-    }
-
-    options = {"ColorCoverage": "Automatic", "MinColorDistance": "Automatic"}
-
-    def apply(self, image, n, prop, evaluation, options):
-        "DominantColors[image_Image, n_Integer, prop_String, OptionsPattern[%(name)s]]"
-
-        py_prop = prop.get_string_value()
-        if py_prop not in ("Color", "LABColor", "Count", "Coverage", "CoverageImage"):
-            return
-
-        color_coverage = self.get_option(options, "ColorCoverage", evaluation)
-        min_color_distance = self.get_option(options, "MinColorDistance", evaluation)
-
-        if (
-            isinstance(min_color_distance, Symbol)
-            and min_color_distance.get_name() == "System`Automatic"
-        ):
-            py_min_color_distance = 0.15
-        else:
-            py_min_color_distance = min_color_distance.round_to_float()
-            if py_min_color_distance is None:
-                return
-
-        if (
-            isinstance(color_coverage, Symbol)
-            and color_coverage.get_name() == "System`Automatic"
-        ):
-            py_min_color_coverage = 0.05
-            py_max_color_coverage = 1.0
-        elif color_coverage.has_form("List", 2):
-            py_min_color_coverage = color_coverage.leaves[0].round_to_float()
-            py_max_color_coverage = color_coverage.leaves[1].round_to_float()
-        else:
-            py_min_color_coverage = color_coverage.round_to_float()
-            py_max_color_coverage = 1.0
-
-        if py_min_color_coverage is None or py_max_color_coverage is None:
-            return
-
-        at_most = n.get_int_value()
-
-        if at_most > 256:
-            return
-
-        # reduce complexity by reducing to 256 colors. this is not uncommon; see Kiranyaz et al.,
-        # "Perceptual Dominant Color Extraction by Multidimensional Particle Swarm Optimization":
-        # "to reduce the computational complexity [...] a preprocessing step, which creates a
-        # limited color palette in RGB color domain, is first performed."
-
-        im = (
-            image.color_convert("RGB")
-            .pil()
-            .convert("P", palette=PIL.Image.ADAPTIVE, colors=256)
-        )
-        pixels = numpy.array(list(im.getdata()))
-
-        flat = numpy.array(list(im.getpalette())) / 255.0  # float values now
-        rgb_palette = [flat[i : i + 3] for i in range(0, len(flat), 3)]  # group by 3
-        lab_palette = [
-            numpy.array(x) for x in convert_color(rgb_palette, "RGB", "LAB", False)
-        ]
-
-        bins = numpy.bincount(pixels, minlength=len(rgb_palette))
-        num_pixels = im.size[0] * im.size[1]
-
-        from mathics.algorithm.clusters import (
-            agglomerate,
-            PrecomputedDistances,
-            FixedDistanceCriterion,
-        )
-
-        norm = numpy.linalg.norm
-
-        def df(i, j):
-            return norm(lab_palette[i] - lab_palette[j])
-
-        lab_distances = [df(i, j) for i in range(len(lab_palette)) for j in range(i)]
-
-        if py_prop == "LABColor":
-            out_palette = lab_palette
-            out_palette_head = "LABColor"
-        else:
-            out_palette = rgb_palette
-            out_palette_head = "RGBColor"
-
-        dominant = agglomerate(
-            (out_palette, bins),
-            (FixedDistanceCriterion, {"merge_limit": py_min_color_distance}),
-            PrecomputedDistances(lab_distances),
-            mode="dominant",
-        )
-
-        def result():
-            min_count = max(0, int(num_pixels * py_min_color_coverage))
-            max_count = min(num_pixels, int(num_pixels * py_max_color_coverage))
-
-            for prototype, count, members in dominant:
-                if max_count >= count > min_count:
-                    if py_prop == "Count":
-                        yield Integer(count)
-                    elif py_prop == "Coverage":
-                        yield Rational(int(count), num_pixels)
-                    elif py_prop == "CoverageImage":
-                        mask = numpy.ndarray(shape=pixels.shape, dtype=numpy.bool)
-                        mask.fill(0)
-                        for i in members:
-                            mask = mask | (pixels == i)
-                        yield Image(mask.reshape(tuple(reversed(im.size))), "Grayscale")
-                    else:
-                        yield Expression(out_palette_head, *prototype)
-
-        return Expression(SymbolList, *itertools.islice(result(), 0, at_most))
-
-
 # pixel access
 
 
@@ -2119,24 +1872,6 @@ class ImageQ(_ImageTest):
         return isinstance(expr, Image)
 
 
-class ImageBox(BoxConstruct):
-    def boxes_to_text(self, leaves=None, **options):
-        return "-Image-"
-
-    def boxes_to_mathml(self, leaves=None, **options):
-        if leaves is None:
-            leaves = self._leaves
-        # see https://tools.ietf.org/html/rfc2397
-        return '<mglyph src="%s" width="%dpx" height="%dpx" />' % (
-            leaves[0].get_string_value(),
-            leaves[1].get_int_value(),
-            leaves[2].get_int_value(),
-        )
-
-    def boxes_to_tex(self, leaves=None, **options):
-        return "-Image-"
-
-
 class Image(Atom):
     def __init__(self, pixels, color_space, metadata={}, **kwargs):
         super(Image, self).__init__(**kwargs)
@@ -2413,151 +2148,160 @@ class TextRecognize(Builtin):
         return String(text)
 
 
-class WordCloud(Builtin):
-    """
-    <dl>
-    <dt>'WordCloud[{$word1$, $word2$, ...}]'
-      <dd>Gives a word cloud with the given list of words.
-    <dt>'WordCloud[{$weight1$ -> $word1$, $weight2$ -> $word2$, ...}]'
-      <dd>Gives a word cloud with the words weighted using the given weights.
-    <dt>'WordCloud[{$weight1$, $weight2$, ...} -> {$word1$, $word2$, ...}]'
-      <dd>Also gives a word cloud with the words weighted using the given weights.
-    <dt>'WordCloud[{{$word1$, $weight1$}, {$word2$, $weight2$}, ...}]'
-      <dd>Gives a word cloud with the words weighted using the given weights.
-    </dl>
+import sys
 
-    >> WordCloud[StringSplit[Import["ExampleData/EinsteinSzilLetter.txt"]]]
-     = -Image-
+if "Pyston" not in sys.version:
 
-    >> WordCloud[Range[50] -> ToString /@ Range[50]]
-     = -Image-
-    """
+    class WordCloud(Builtin):
+        """
+        <dl>
+        <dt>'WordCloud[{$word1$, $word2$, ...}]'
+          <dd>Gives a word cloud with the given list of words.
+        <dt>'WordCloud[{$weight1$ -> $word1$, $weight2$ -> $word2$, ...}]'
+          <dd>Gives a word cloud with the words weighted using the given weights.
+        <dt>'WordCloud[{$weight1$, $weight2$, ...} -> {$word1$, $word2$, ...}]'
+          <dd>Also gives a word cloud with the words weighted using the given weights.
+        <dt>'WordCloud[{{$word1$, $weight1$}, {$word2$, $weight2$}, ...}]'
+          <dd>Gives a word cloud with the words weighted using the given weights.
+        </dl>
 
-    requires = _image_requires + ("wordcloud",)
+        >> WordCloud[StringSplit[Import["ExampleData/EinsteinSzilLetter.txt"]]]
+         = -Image-
 
-    options = {"IgnoreCase": "True", "ImageSize": "Automatic", "MaxItems": "Automatic"}
+        >> WordCloud[Range[50] -> ToString /@ Range[50]]
+         = -Image-
+        """
 
-    # this is the palettable.colorbrewer.qualitative.Dark2_8 palette
-    default_colors = (
-        (27, 158, 119),
-        (217, 95, 2),
-        (117, 112, 179),
-        (231, 41, 138),
-        (102, 166, 30),
-        (230, 171, 2),
-        (166, 118, 29),
-        (102, 102, 102),
-    )
+        requires = _image_requires + ("wordcloud",)
 
-    def apply_words_weights(self, weights, words, evaluation, options):
-        "WordCloud[weights_List -> words_List, OptionsPattern[%(name)s]]"
-        if len(weights.leaves) != len(words.leaves):
-            return
+        options = {
+            "IgnoreCase": "True",
+            "ImageSize": "Automatic",
+            "MaxItems": "Automatic",
+        }
 
-        def weights_and_words():
-            for weight, word in zip(weights.leaves, words.leaves):
-                yield weight.round_to_float(), word.get_string_value()
-
-        return self._word_cloud(weights_and_words(), evaluation, options)
-
-    def apply_words(self, words, evaluation, options):
-        "WordCloud[words_List, OptionsPattern[%(name)s]]"
-
-        if not words:
-            return
-        elif isinstance(words.leaves[0], String):
-
-            def weights_and_words():
-                for word in words.leaves:
-                    yield 1, word.get_string_value()
-
-        else:
-
-            def weights_and_words():
-                for word in words.leaves:
-                    if len(word.leaves) != 2:
-                        raise ValueError
-
-                    head_name = word.get_head_name()
-                    if head_name == "System`Rule":
-                        weight, s = word.leaves
-                    elif head_name == "System`List":
-                        s, weight = word.leaves
-                    else:
-                        raise ValueError
-
-                    yield weight.round_to_float(), s.get_string_value()
-
-        try:
-            return self._word_cloud(weights_and_words(), evaluation, options)
-        except ValueError:
-            return
-
-    def _word_cloud(self, words, evaluation, options):
-        ignore_case = self.get_option(options, "IgnoreCase", evaluation) == Symbol(
-            "True"
+        # this is the palettable.colorbrewer.qualitative.Dark2_8 palette
+        default_colors = (
+            (27, 158, 119),
+            (217, 95, 2),
+            (117, 112, 179),
+            (231, 41, 138),
+            (102, 166, 30),
+            (230, 171, 2),
+            (166, 118, 29),
+            (102, 102, 102),
         )
 
-        freq = defaultdict(int)
-        for py_weight, py_word in words:
-            if py_word is None or py_weight is None:
+        def apply_words_weights(self, weights, words, evaluation, options):
+            "WordCloud[weights_List -> words_List, OptionsPattern[%(name)s]]"
+            if len(weights.leaves) != len(words.leaves):
                 return
-            key = py_word.lower() if ignore_case else py_word
-            freq[key] += py_weight
 
-        max_items = self.get_option(options, "MaxItems", evaluation)
-        if isinstance(max_items, Integer):
-            py_max_items = max_items.get_int_value()
-        else:
-            py_max_items = 200
+            def weights_and_words():
+                for weight, word in zip(weights.leaves, words.leaves):
+                    yield weight.round_to_float(), word.get_string_value()
 
-        image_size = self.get_option(options, "ImageSize", evaluation)
-        if image_size == Symbol("Automatic"):
-            py_image_size = (800, 600)
-        elif (
-            image_size.get_head_name() == "System`List" and len(image_size.leaves) == 2
-        ):
-            py_image_size = []
-            for leaf in image_size.leaves:
-                if not isinstance(leaf, Integer):
+            return self._word_cloud(weights_and_words(), evaluation, options)
+
+        def apply_words(self, words, evaluation, options):
+            "WordCloud[words_List, OptionsPattern[%(name)s]]"
+
+            if not words:
+                return
+            elif isinstance(words.leaves[0], String):
+
+                def weights_and_words():
+                    for word in words.leaves:
+                        yield 1, word.get_string_value()
+
+            else:
+
+                def weights_and_words():
+                    for word in words.leaves:
+                        if len(word.leaves) != 2:
+                            raise ValueError
+
+                        head_name = word.get_head_name()
+                        if head_name == "System`Rule":
+                            weight, s = word.leaves
+                        elif head_name == "System`List":
+                            s, weight = word.leaves
+                        else:
+                            raise ValueError
+
+                        yield weight.round_to_float(), s.get_string_value()
+
+            try:
+                return self._word_cloud(weights_and_words(), evaluation, options)
+            except ValueError:
+                return
+
+        def _word_cloud(self, words, evaluation, options):
+            ignore_case = self.get_option(options, "IgnoreCase", evaluation) == Symbol(
+                "True"
+            )
+
+            freq = defaultdict(int)
+            for py_weight, py_word in words:
+                if py_word is None or py_weight is None:
                     return
-                py_image_size.append(leaf.get_int_value())
-        elif isinstance(image_size, Integer):
-            size = image_size.get_int_value()
-            py_image_size = (size, size)
-        else:
-            return
+                key = py_word.lower() if ignore_case else py_word
+                freq[key] += py_weight
 
-        # inspired by http://minimaxir.com/2016/05/wordclouds/
-        import random
-        import os
+            max_items = self.get_option(options, "MaxItems", evaluation)
+            if isinstance(max_items, Integer):
+                py_max_items = max_items.get_int_value()
+            else:
+                py_max_items = 200
 
-        def color_func(
-            word, font_size, position, orientation, random_state=None, **kwargs
-        ):
-            return self.default_colors[random.randint(0, 7)]
+            image_size = self.get_option(options, "ImageSize", evaluation)
+            if image_size == Symbol("Automatic"):
+                py_image_size = (800, 600)
+            elif (
+                image_size.get_head_name() == "System`List"
+                and len(image_size.leaves) == 2
+            ):
+                py_image_size = []
+                for leaf in image_size.leaves:
+                    if not isinstance(leaf, Integer):
+                        return
+                    py_image_size.append(leaf.get_int_value())
+            elif isinstance(image_size, Integer):
+                size = image_size.get_int_value()
+                py_image_size = (size, size)
+            else:
+                return
 
-        font_base_path = os.path.dirname(os.path.abspath(__file__)) + "/../fonts/"
+            # inspired by http://minimaxir.com/2016/05/wordclouds/
+            import random
+            import os
 
-        font_path = os.path.realpath(font_base_path + "AmaticSC-Bold.ttf")
-        if not os.path.exists(font_path):
-            font_path = None
+            def color_func(
+                word, font_size, position, orientation, random_state=None, **kwargs
+            ):
+                return self.default_colors[random.randint(0, 7)]
 
-        from wordcloud import WordCloud
+            font_base_path = os.path.dirname(os.path.abspath(__file__)) + "/../fonts/"
 
-        wc = WordCloud(
-            width=py_image_size[0],
-            height=py_image_size[1],
-            font_path=font_path,
-            max_font_size=300,
-            mode="RGB",
-            background_color="white",
-            max_words=py_max_items,
-            color_func=color_func,
-            random_state=42,
-            stopwords=set(),
-        )
-        wc.generate_from_frequencies(freq)
+            font_path = os.path.realpath(font_base_path + "AmaticSC-Bold.ttf")
+            if not os.path.exists(font_path):
+                font_path = None
 
-        image = wc.to_image()
-        return Image(numpy.array(image), "RGB")
+            from wordcloud import WordCloud
+
+            wc = WordCloud(
+                width=py_image_size[0],
+                height=py_image_size[1],
+                font_path=font_path,
+                max_font_size=300,
+                mode="RGB",
+                background_color="white",
+                max_words=py_max_items,
+                color_func=color_func,
+                random_state=42,
+                stopwords=set(),
+            )
+            wc.generate_from_frequencies(freq)
+
+            image = wc.to_image()
+            return Image(numpy.array(image), "RGB")
