@@ -41,6 +41,30 @@ def valuesname(name) -> str:
         return name[7:-6].lower()
 
 
+def autoload_files(
+    defs, root_dir_path: str, autoload_dir: str, block_global_definitions: bool = True
+):
+    from mathics.core.evaluation import Evaluation
+
+    # Load symbols from the autoload folder
+    for root, dirs, files in os.walk(os.path.join(root_dir_path, autoload_dir)):
+        for path in [os.path.join(root, f) for f in files if f.endswith(".m")]:
+            Expression("Get", String(path)).evaluate(Evaluation(defs))
+
+    if block_global_definitions:
+        # Move any user definitions created by autoloaded files to
+        # builtins, and clear out the user definitions list. This
+        # means that any autoloaded definitions become shared
+        # between users and no longer disappear after a Quit[].
+        #
+        # Autoloads that accidentally define a name in Global`
+        # could cause confusion, so check for this.
+
+        for name in defs.user:
+            if name.startswith("Global`"):
+                raise ValueError("autoload defined %s." % name)
+
+
 class PyMathicsLoadException(Exception):
     def __init__(self, module):
         self.name = module + " is not a valid pymathics module"
@@ -63,7 +87,6 @@ class Definitions(object):
 
         if add_builtin:
             from mathics.builtin import modules, contribute
-            from mathics.core.evaluation import Evaluation
             from mathics.settings import ROOT_DIR
 
             loaded = False
@@ -78,22 +101,17 @@ class Definitions(object):
                 contribute(self)
                 for module in extension_modules:
                     try:
-                        loaded_module = self.load_pymathics_module(
-                            module, remove_on_quit=False
-                        )
-                    except PyMathicsLoadException as e:
+                        self.load_pymathics_module(module, remove_on_quit=False)
+                    except PyMathicsLoadException:
                         raise
-                    except ImportError as e:
+                    except ImportError:
                         raise
 
                 if builtin_filename is not None:
                     builtin_file = open(builtin_filename, "wb")
                     pickle.dump(self.builtin, builtin_file, -1)
 
-            # Load symbols from the autoload folder
-            for root, dirs, files in os.walk(os.path.join(ROOT_DIR, "autoload")):
-                for path in [os.path.join(root, f) for f in files if f.endswith(".m")]:
-                    Expression("Get", String(path)).evaluate(Evaluation(self))
+            autoload_files(self, ROOT_DIR, "autoload")
 
             # Move any user definitions created by autoloaded files to
             # builtins, and clear out the user definitions list. This
@@ -106,10 +124,16 @@ class Definitions(object):
             for name in self.user:
                 if name.startswith("Global`"):
                     raise ValueError("autoload defined %s." % name)
+
             self.builtin.update(self.user)
             self.user = {}
             self.clear_cache()
 
+        # FIXME load dynamically as we do other things
+        import mathics.format.asy  # noqa
+        import mathics.format.json  # noqa
+        import mathics.format.svg  # noqa
+
     def load_pymathics_module(self, module, remove_on_quit=True):
         """
         Loads Mathics builtin objects and their definitions
@@ -370,11 +394,11 @@ class Definitions(object):
             return name
 
         with_context = current_context + name
-        if not self.have_definition(with_context):
-            for ctx in self.get_context_path():
-                n = ctx + name
-                if self.have_definition(n):
-                    return n
+        # if not self.have_definition(with_context):
+        for ctx in self.get_context_path():
+            n = ctx + name
+            if self.have_definition(n):
+                return n
         return with_context
 
     def get_package_names(self) -> typing.List[str]:
@@ -475,6 +499,8 @@ class Definitions(object):
             self.lookup_cache[original_name] = name
         elif not only_if_exists:
             definition = Definition(name=name)
+            if name[-1] != "`":
+                self.user[name] = definition
 
         return definition
 
@@ -722,7 +748,7 @@ def get_tag_position(pattern, name) -> typing.Optional[str]:
 
 def insert_rule(values, rule) -> None:
     for index, existing in enumerate(values):
-        if existing.pattern.same(rule.pattern):
+        if existing.pattern.sameQ(rule.pattern):
             del values[index]
             break
     # use insort_left to guarantee that if equal rules exist, newer rules will
@@ -818,7 +844,7 @@ class Definition(object):
         if position:
             values = self.get_values_list(position)
             for index, existing in enumerate(values):
-                if existing.pattern.expr.same(lhs):
+                if existing.pattern.expr.sameQ(lhs):
                     del values[index]
                     return True
         return False
