@@ -1,10 +1,8 @@
-
 # -*- coding: utf-8 -*-
 from .helper import check_evaluation
 from mathics_scanner.errors import IncompleteSyntaxError
 
 
-
 str_test_context = """
 BeginPackage["FeynCalc`"];
 
@@ -42,6 +40,7 @@ End[];
 EndPackage[];
 """
 
+
 def test_context1():
     expr = ""
     for line in str_test_context.split("\n"):
@@ -49,11 +48,13 @@ def test_context1():
             continue
         expr = expr + line
         try:
-            print("expr=",expr)
-            check_evaluation(expr, "Null", to_string_expr=False, to_string_expected=False)
+            print("expr=", expr)
+            check_evaluation(
+                expr, "Null", to_string_expr=False, to_string_expected=False
+            )
             expr = ""
             print("  OK")
         except IncompleteSyntaxError:
             continue
-    check_evaluation("foo[42]", '42', to_string_expr=False, to_string_expected=False)
-    check_evaluation("bar[]", '42', to_string_expr=False, to_string_expected=False)
+    check_evaluation("foo[42]", "42", to_string_expr=False, to_string_expected=False)
+    check_evaluation("bar[]", "42", to_string_expr=False, to_string_expected=False)
